Struct SignalValueExtractor
pub struct SignalValueExtractor {
bits: SignalBitsExtractor,
factor: f64,
offset: f64,
is_signed: bool,
min: f64,
max: f64,
}Expand description
Helper for extracting a DBC signal value from CAN frame data.
Fields
bits: SignalBitsExtractorfactor: f64offset: f64is_signed: boolmin: f64max: f64Implementations
impl SignalValueExtractor
impl SignalValueExtractor
fn from_dbc_signal(signal: &Signal) -> Result<Self>
fn extract_raw_unchecked(&self, data: &[u8]) -> Option<f64>
pub fn extract_unchecked(&self, data: &[u8]) -> Option<f64>
pub fn extract_unchecked(&self, data: &[u8]) -> Option<f64>
Extracts the unchecked signal value from the CAN frame data.
This does not check for min/max limits and just returns the raw value
multiplied by the factor and added to the offset.
It still returns None if the resulting value is non-finite (NaN or
infinity). This is possible if the raw value combined with the
factor and offset results in a value that is large enough to spill over
to infinity in floating point math.
See Self::extract for a version that also checks the min/max limits.
pub fn extract(&self, data: &[u8]) -> Option<f64>
pub fn extract(&self, data: &[u8]) -> Option<f64>
Extracts the signal value from the CAN frame data.
Returns None if the value is out of the min/max limits or if the value
is non-finite (NaN or infinity). See Self::extract_unchecked for
a version that does not check the min/max limits.